@@ -1,7 +1,7 @@
 ################################################################################
 ##
 ##   R package reda by Wenjie Wang, Haoda Fu, and Jun Yan
-##   Copyright (C) 2015-2016
+##   Copyright (C) 2015-2017
 ##
 ##   This file is part of the R package reda.
 ##
@@ -28,21 +28,26 @@ NULL
 ##' An S4 class generic function that returns the estimated baseline rate
 ##' function.
 ##'
+##' @aliases baseRate
+##'
 ##' @param object An object used to dispatch a method.
 ##' @param ... Other arguments for future usage.
-##' @aliases baseRate
+##'
 ##' @return A \code{baseRate} object.
+##'
 ##' @examples
 ##' ## See examples given in function rateReg.
 ##' @seealso
 ##' \code{\link{rateReg}} for model fitting;
 ##' \code{\link{summary,rateReg-method}} for summary of a fitted model;
-##' \code{\link{plot,baseRateReg-method}} for ploting method.
+##' \code{\link{plot,baseRate.rateReg-method}} for ploting method.
 ##' @export
-setGeneric(name = "baseRate",
-           def = function(object, ...) {
-               standardGeneric("baseRate")
-           })
+setGeneric(
+    name = "baseRate",
+    def = function(object, ...) {
+        standardGeneric("baseRate")
+    }
+)
 
 
 ##' @describeIn baseRate Estiamted baseline rate from a fitted model.
@@ -63,12 +68,15 @@ setGeneric(name = "baseRate",
 ##' When \code{grid} is missing, the grid will be generated
 ##' by \code{seq} (from package \pkg{base})
 ##' with arguments \code{from}, \code{to} and \code{length.out}.
+##'
 ##' @aliases baseRate,rateReg-method
+##'
 ##' @importFrom stats qnorm
-##' @importFrom splines2 bSpline mSpline
+##'
 ##' @export
 setMethod(
-    f = "baseRate", signature = "rateReg",
+    f = "baseRate",
+    signature = "rateReg",
     definition = function(object, level = 0.95, control = list(), ...) {
 
         ## baseline rate coefficients
@@ -105,19 +113,29 @@ setMethod(
         nBeta <- nrow(object@estimates$beta)
         ind <- seq_len(nBeta + 1L)
         covMat <- solve(object@fisher)[- ind, - ind, drop = FALSE]
-        seVec <- apply(bMat, 1L, function (bVec, covMat) {
-                sqrt(crossprod(bVec, covMat) %*% bVec)
+        varVec <- apply(bMat, 1L, function (bVec, covMat) {
+            crossprod(bVec, covMat) %*% bVec
         }, covMat = covMat)
 
+        seVec <- tryCatch(sqrt(varVec), warning = function(w) w)
+        if ("warning" %in% class(seVec)) {
+            stop(wrapMessages(
+                "The variance-covariance matrix is not positive definite.",
+                "Please check possible error",
+                "(or adjust spline bases and perhaps",
+                "try different set of starting values)."
+            ))
+        }
+
         ## confidence interval for the given level
         confBand <- stats::qnorm((1 + level) / 2) * seVec
-        lower <- pmax(0, estVec - confBand)
+        lower <- estVec - confBand
         upper <- estVec + confBand
 
         ## prepare for output
         outDat <- data.frame(time = gridTime, baseRate = estVec,
                              se = seVec, lower = lower, upper = upper)
-        out <- new("baseRateReg",
-                   baseRate = outDat,
-                   level = level)
+        methods::new("baseRate.rateReg",
+                     baseRate = outDat,
+                     level = level)
     })
