@@ -6,9 +6,9 @@
 // [[Rcpp::export]]
 Rcpp::NumericVector rrisk_exponential(arma::mat z, arma::mat zCoef)
 {
-  unsigned int nrow_z {z.n_rows};
+  unsigned int nrow_z = z.n_rows;
   Rcpp::NumericVector res(nrow_z);
-  for (size_t i {0}; i < nrow_z; ++i) {
+  for (size_t i = 0; i < nrow_z; ++i) {
     res[i] = std::exp(arma::sum(z.row(i) % zCoef.row(i)));
   }
   return res;
@@ -17,9 +17,9 @@ Rcpp::NumericVector rrisk_exponential(arma::mat z, arma::mat zCoef)
 // [[Rcpp::export]]
 Rcpp::NumericVector rrisk_linear(arma::mat z, arma::mat zCoef)
 {
-  unsigned int nrow_z {z.n_rows};
+  unsigned int nrow_z = z.n_rows;
   Rcpp::NumericVector res(nrow_z);
-  for (size_t i {0}; i < nrow_z; ++i) {
+  for (size_t i = 0; i < nrow_z; ++i) {
     res[i] = 1 + arma::sum(z.row(i) % zCoef.row(i));
   }
   return res;
@@ -28,9 +28,9 @@ Rcpp::NumericVector rrisk_linear(arma::mat z, arma::mat zCoef)
 // [[Rcpp::export]]
 Rcpp::NumericVector rrisk_excess(arma::mat z, arma::mat zCoef)
 {
-  unsigned int nrow_z {z.n_rows};
+  unsigned int nrow_z = z.n_rows;
   Rcpp::NumericVector res(nrow_z);
-  for (size_t i {0}; i < nrow_z; ++i) {
+  for (size_t i = 0; i < nrow_z; ++i) {
     res[i] = std::exp(arma::sum(arma::log(1 + z.row(i) % zCoef.row(i))));
   }
   return res;
